/*
 * AbugraphAppletStub.java
 *
 * Copyright (c) 2007 Ignacio Labrador Pavon
 * 28814 Daganzo, Madrid.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of copyright holders nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL COPYRIGHT HOLDERS OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package net.sourceforge.abugraph;

import java.applet.Applet;
import java.applet.AppletContext;
import java.applet.AppletStub;
import java.net.InetAddress;
import java.net.UnknownHostException;
import java.util.HashMap;
import java.util.NoSuchElementException;
import java.util.StringTokenizer;


/**
 * This class is used to execute the applet as an application. The class
 * 'AppletStub' is usually created by the web browsers every time that a new
 * appled has to be loaded in order to provide the necessary information
 * to load execute the applet.
 * 
 * This is a single implementation used to do the following tasks:
 * 
 * <li> Decode the command line arguments
 * <li> Returns valid values for 'getCodeBase()' and 'getDocumentBase()'
 * 
 * @author ilp
 * @since  20/Aug/2007
 */
public class AbugraphAppletStub implements AppletStub
{  
  //~Constants ----------------------------------------------------------------
  private final static String FILE_PROTOCOL = "file://";
  private final static String HOST_STR      = "host";
  private final static String EQUALS_STR    = "=";
  private final static String SLASH_STR     = "\"";
  
  //~Variables ----------------------------------------------------------------
  private HashMap<String, String> props  = null;
  private Applet                  applet = null;

  //~Methods ------------------------------------------------------------------
  
  /**
   * Constructor
   */
  public AbugraphAppletStub(String[] args, Applet app)
  throws NoSuchElementException
  {
    applet = app;
    props = new HashMap<String,String>();
    for (int i = 0; i < args.length; i++)
    {
      StringTokenizer parser = new StringTokenizer(args[i], EQUALS_STR);
      String name = parser.nextToken().toString();
      String value = parser.nextToken(SLASH_STR).toString();
      value = value.substring(1);
      props.put(name, value);
    }
  }

  /** 
   * Requests that this applet be resized.
   *
   * @param   width    the new requested width for the applet.
   * @param   height   the new requested height for the applet.
   */
  public void appletResize(int width, int height)
  {
    applet.resize(width, height);
  }

  /**
   * Returns the codebase. If 'host' is not provided as a command line argument
   * the URL is bases on the 'InetAddress.getLocalHost()' method. 
   */
  public java.net.URL getCodeBase()
  {
    String host;
    if ((host = getParameter(HOST_STR)) == null)
    {
      try
      {
        host = InetAddress.getLocalHost().getHostName();
      }
      catch (UnknownHostException e)
      {
        e.printStackTrace();
      }
    }
    
    java.net.URL url = null;
    try
    {
      url = new java.net.URL(FILE_PROTOCOL + host);
    }
    catch (Exception e)
    {
      e.printStackTrace();
    }
    return url;
  }
  
  /**
   * The applet is always active
   */
  public boolean isActive()
  {
    return true;
  }
  
  /**
   * Returns the document base URL
   */
  public java.net.URL getDocumentBase()
  {
    return getCodeBase();
  }

  /**
   * Returns the argument provided as command line parameter
   */
  public String getParameter(String param)
  {
    return ((String) props.get(param));
  }

  /**
   * Returns the applet context (null for this case).
   */
  public AppletContext getAppletContext()
  {
    return null;
  }
}
