/*
 * MessageDialog.java
 *
 * Copyright (c) 2007 Ignacio Labrador Pavon
 * 28814 Daganzo, Madrid.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of copyright holders nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL COPYRIGHT HOLDERS OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package net.sourceforge.abugraph;

import java.awt.Container;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JFrame;
import javax.swing.JLabel;

/**
 * Confirmation dialog class: the typical dialog with a message and a single
 * 'OK' button.
 *
 * @author ilp
 * @since 19/Sept/2007
 */
public class MessageDialog extends JDialog
{
  public MessageDialog(final JFrame ar_frame, String ar_msg)
  {
    super(ar_frame, "Message", true);
    
    String[] lines = ar_msg.split("\\n");
    
    Container cp = getContentPane();
    cp.setLayout(null); //Means Absolute layout
    cp.setLocation(ar_frame.getWidth()/2,ar_frame.getHeight()/2);
    cp.setVisible(true);
    
    int text_len = 0;
    
    for(int i=0; i<lines.length; i++)
    {
      if(7*lines[i].length() > text_len) text_len = 7*lines[i].length(); 
      JLabel label = new JLabel(lines[i]);
      label.setLocation(22,15+(20*i));
      label.setSize(text_len,20);
      label.setVisible(true);
      cp.add(label);
    }
    
    int width = 22 + text_len + 22;
    int height = 130;
    
    JButton ok = new JButton("OK");
    int ok_width = 85;
    ok.setSize(ok_width,30);
    ok.setLocation( (width/2)-(ok_width/2),40+20*lines.length);
 
    ok.addActionListener(new ActionListener()
    {
      public void actionPerformed(ActionEvent e)
      {
        dispose();
      }
    });
    
    cp.add(ok);
    setSize(width,height+(20*lines.length));
  }
}
