/*
 * ConfirmationDialog.java
 *
 * Copyright (c) 2007 Ignacio Labrador Pavon
 * 28814 Daganzo, Madrid.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of copyright holders nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL COPYRIGHT HOLDERS OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package net.sourceforge.abugraph;

import java.awt.Container;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JFrame;
import javax.swing.JLabel;

/**
 * Confirmation dialog class: the typical 'OK' / 'CANCEL' dialog to perform
 * operations such exit or clear.
 *
 * @author ilp
 * @since 17/Sept/2007
 */
public class ConfirmationDialog extends JDialog
{
  public ConfirmationDialog(final JFrame frame, final Abugraph parent)
  {
    super(frame, "Are you sure...?", true);
    Container cp = getContentPane();
    cp.setLayout(null); //Means Absolute layout
    cp.setLocation(200,300);
    
    JLabel label = new JLabel("Confirm please");
    label.setLocation(92,15);
    label.setVisible(true);
    label.setSize(280,20);
    
    JButton ok = new JButton("OK");
    ok.setSize(85,30);
    ok.setLocation(40,50);
    
    JButton cancel = new JButton("CANCEL");
    cancel.setSize(85,30);
    cancel.setLocation(150,50);
 
    ok.addActionListener(new ActionListener()
    {
      public void actionPerformed(ActionEvent e)
      {
        dispose(); 
        if(parent.wasCalledToExit())
          System.exit(0);
        else if(parent.wasCalledToClear())
          parent.getPanel().clear();
      }
    });
    
    cancel.addActionListener(new ActionListener()
    {
      public void actionPerformed(ActionEvent e)
      {
        dispose(); // Just closes the dialog
      }
    });
    
    cp.add(label);
    cp.add(ok);
    cp.add(cancel);
    setSize(290,130);
  }
}
